import { ComponentMetadata, Snippet } from '@alilc/lowcode-types';
const DividerMeta: ComponentMetadata = {
  group: '原子组件',
  category: '通用',
  title: '分隔符',
  componentName: 'Divider',
  npm: {
    package: '@alifd/next',
    version: '{{version}}',
    exportName: 'Divider',
    main: '',
    destructuring: true,
    subName: '',
  },
  props: [
    {
      name: 'style',
      propType: 'object',
      description: '自定义内敛样式',
    },
    {
      name: 'children',
      propType: 'string',
      description: '文案',
      defaultValue: '分隔符',
    },
    {
      name: 'dashed',
      propType: {
        type: 'bool',
      },
      description: '是否为虚线',
      defaultValue: false,
    },
    {
      name: 'direction',
      propType: {
        type: 'oneOf',
        value: ['hoz', 'ver'],
      },
      description: '线是水平还是垂直类型',
      defaultValue: 'hoz',
    },
    {
      name: 'orientation',
      propType: {
        type: 'oneOf',
        value: ['left', 'right', 'center'],
      },
      description: '分割线标题的位置',
      defaultValue: 'center',
    },
  ],
  configure: {
    props: [
      {
        name: 'direction',
        title: {
          label: {
            type: 'i18n',
            zh_CN: '方向',
            en_US: 'Direction',
          },
        },
        setter: {
          componentName: 'RadioGroupSetter',
          props: {
            options: [
              {
                label: '水平',
                value: 'hoz',
              },
              {
                label: '垂直',
                value: 'ver',
              },
            ],
          },
        },
        setValue: (target, value) => {
          if (value === 'ver') {
            target.parent.setPropValue('children', '');
          }
        },
        defaultValue: 'hoz',
      },
      {
        name: 'children',
        setter: 'StringSetter',
        title: '文本内容',
        defaultValue: '分隔符',
        condition: (target) => target?.parent?.getPropValue?.('direction') !== 'ver',
      },
      {
        name: 'orientation',
        title: {
          label: {
            type: 'i18n',
            zh_CN: '对齐方式',
            en_US: 'Orientation',
          },
        },
        condition: (target) => target?.parent?.getPropValue?.('direction') !== 'ver',
        setter: {
          componentName: 'RadioGroupSetter',
          props: {
            options: [
              {
                label: '居中',
                value: 'center',
              },
              {
                label: '居左',
                value: 'left',
              },
              {
                label: '居右',
                value: 'right',
              },
            ],
          },
        },
        defaultValue: 'center',
      },
      {
        name: 'dashed',
        title: {
          label: {
            type: 'i18n',
            zh_CN: '样式',
            en_US: 'Dashed',
          },
        },
        setter: {
          componentName: 'RadioGroupSetter',
          props: {
            options: [
              {
                label: '实线',
                value: false,
              },
              {
                label: '虚线',
                value: true,
              },
            ],
          },
        },
        defaultValue: true,
      },
    ],
  },
};
const snippets: Snippet[] = [
  {
    "title": "分隔符",
    "screenshot": "https://alifd.oss-cn-hangzhou.aliyuncs.com/fusion-cool/icons/icon-light/ic_light_divider.png",
    "schema": {
      "componentName": "Divider",
      "props": {
      }
    }
  }
];

export default {
  ...DividerMeta,
  snippets
};